use strict;
use Test::More;

plan tests => 13;
use_ok("Net::Delicious");
use_ok("Net::Delicious::Bundle");
use_ok("Net::Delicious::Constants");
use_ok("Net::Delicious::Constants::Api");
use_ok("Net::Delicious::Constants::Pause");
use_ok("Net::Delicious::Constants::Response");
use_ok("Net::Delicious::Constants::Uri");
use_ok("Net::Delicious::Date");
use_ok("Net::Delicious::Iterator");
use_ok("Net::Delicious::Object");
use_ok("Net::Delicious::Post");
# use_ok("Net::Delicious::Subscription");
use_ok("Net::Delicious::Tag");
use_ok("Net::Delicious::User");